@@ -48,6 +48,7 @@ from .type_defs import (
     DimensionFilterTypeDef,
     DimensionTypeDef,
     DisableInsightRulesOutputTypeDef,
+    EmptyResponseMetadataTypeDef,
     EnableInsightRulesOutputTypeDef,
     GetDashboardOutputTypeDef,
     GetInsightRuleReportOutputTypeDef,
@@ -131,7 +132,15 @@ class CloudWatchClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client/#can_paginate)
         """
 
-    def delete_alarms(self, *, AlarmNames: Sequence[str]) -> None:
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client/#close)
+        """
+
+    def delete_alarms(self, *, AlarmNames: Sequence[str]) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the specified alarms.
 
@@ -144,10 +153,10 @@ class CloudWatchClient(BaseClient):
         *,
         Namespace: str = ...,
         MetricName: str = ...,
-        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Dimensions: Sequence[DimensionTypeDef] = ...,
         Stat: str = ...,
-        SingleMetricAnomalyDetector: "SingleMetricAnomalyDetectorTypeDef" = ...,
-        MetricMathAnomalyDetector: "MetricMathAnomalyDetectorTypeDef" = ...
+        SingleMetricAnomalyDetector: SingleMetricAnomalyDetectorTypeDef = ...,
+        MetricMathAnomalyDetector: MetricMathAnomalyDetectorTypeDef = ...
     ) -> Dict[str, Any]:
         """
         Deletes the specified anomaly detection model from your account.
@@ -226,7 +235,7 @@ class CloudWatchClient(BaseClient):
         Namespace: str,
         Statistic: StatisticType = ...,
         ExtendedStatistic: str = ...,
-        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Dimensions: Sequence[DimensionTypeDef] = ...,
         Period: int = ...,
         Unit: StandardUnitType = ...
     ) -> DescribeAlarmsForMetricOutputTypeDef:
@@ -244,7 +253,7 @@ class CloudWatchClient(BaseClient):
         MaxResults: int = ...,
         Namespace: str = ...,
         MetricName: str = ...,
-        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Dimensions: Sequence[DimensionTypeDef] = ...,
         AnomalyDetectorTypes: Sequence[AnomalyDetectorTypeType] = ...
     ) -> DescribeAnomalyDetectorsOutputTypeDef:
         """
@@ -264,7 +273,7 @@ class CloudWatchClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client/#describe_insight_rules)
         """
 
-    def disable_alarm_actions(self, *, AlarmNames: Sequence[str]) -> None:
+    def disable_alarm_actions(self, *, AlarmNames: Sequence[str]) -> EmptyResponseMetadataTypeDef:
         """
         Disables the actions for the specified alarms.
 
@@ -282,7 +291,7 @@ class CloudWatchClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client/#disable_insight_rules)
         """
 
-    def enable_alarm_actions(self, *, AlarmNames: Sequence[str]) -> None:
+    def enable_alarm_actions(self, *, AlarmNames: Sequence[str]) -> EmptyResponseMetadataTypeDef:
         """
         Enables the actions for the specified alarms.
 
@@ -342,13 +351,13 @@ class CloudWatchClient(BaseClient):
     def get_metric_data(
         self,
         *,
-        MetricDataQueries: Sequence["MetricDataQueryTypeDef"],
+        MetricDataQueries: Sequence[MetricDataQueryTypeDef],
         StartTime: Union[datetime, str],
         EndTime: Union[datetime, str],
         NextToken: str = ...,
         ScanBy: ScanByType = ...,
         MaxDatapoints: int = ...,
-        LabelOptions: "LabelOptionsTypeDef" = ...
+        LabelOptions: LabelOptionsTypeDef = ...
     ) -> GetMetricDataOutputTypeDef:
         """
         You can use the `GetMetricData` API to retrieve CloudWatch metric values.
@@ -365,7 +374,7 @@ class CloudWatchClient(BaseClient):
         StartTime: Union[datetime, str],
         EndTime: Union[datetime, str],
         Period: int,
-        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Dimensions: Sequence[DimensionTypeDef] = ...,
         Statistics: Sequence[StatisticType] = ...,
         ExtendedStatistics: Sequence[str] = ...,
         Unit: StandardUnitType = ...
@@ -421,7 +430,7 @@ class CloudWatchClient(BaseClient):
         *,
         Namespace: str = ...,
         MetricName: str = ...,
-        Dimensions: Sequence["DimensionFilterTypeDef"] = ...,
+        Dimensions: Sequence[DimensionFilterTypeDef] = ...,
         NextToken: str = ...,
         RecentlyActive: Literal["PT3H"] = ...
     ) -> ListMetricsOutputTypeDef:
@@ -445,11 +454,11 @@ class CloudWatchClient(BaseClient):
         *,
         Namespace: str = ...,
         MetricName: str = ...,
-        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Dimensions: Sequence[DimensionTypeDef] = ...,
         Stat: str = ...,
-        Configuration: "AnomalyDetectorConfigurationTypeDef" = ...,
-        SingleMetricAnomalyDetector: "SingleMetricAnomalyDetectorTypeDef" = ...,
-        MetricMathAnomalyDetector: "MetricMathAnomalyDetectorTypeDef" = ...
+        Configuration: AnomalyDetectorConfigurationTypeDef = ...,
+        SingleMetricAnomalyDetector: SingleMetricAnomalyDetectorTypeDef = ...,
+        MetricMathAnomalyDetector: MetricMathAnomalyDetectorTypeDef = ...
     ) -> Dict[str, Any]:
         """
         Creates an anomaly detection model for a CloudWatch metric.
@@ -468,8 +477,11 @@ class CloudWatchClient(BaseClient):
         AlarmDescription: str = ...,
         InsufficientDataActions: Sequence[str] = ...,
         OKActions: Sequence[str] = ...,
-        Tags: Sequence["TagTypeDef"] = ...
-    ) -> None:
+        Tags: Sequence[TagTypeDef] = ...,
+        ActionsSuppressor: str = ...,
+        ActionsSuppressorWaitPeriod: int = ...,
+        ActionsSuppressorExtensionPeriod: int = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Creates or updates a *composite alarm*.
 
@@ -492,7 +504,7 @@ class CloudWatchClient(BaseClient):
         RuleName: str,
         RuleDefinition: str,
         RuleState: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> Dict[str, Any]:
         """
         Creates a Contributor Insights rule.
@@ -516,17 +528,17 @@ class CloudWatchClient(BaseClient):
         Namespace: str = ...,
         Statistic: StatisticType = ...,
         ExtendedStatistic: str = ...,
-        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Dimensions: Sequence[DimensionTypeDef] = ...,
         Period: int = ...,
         Unit: StandardUnitType = ...,
         DatapointsToAlarm: int = ...,
         Threshold: float = ...,
         TreatMissingData: str = ...,
         EvaluateLowSampleCountPercentile: str = ...,
-        Metrics: Sequence["MetricDataQueryTypeDef"] = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Metrics: Sequence[MetricDataQueryTypeDef] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         ThresholdMetricId: str = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Creates or updates an alarm and associates it with the specified metric, metric
         math expression, or anomaly detection model.
@@ -536,8 +548,8 @@ class CloudWatchClient(BaseClient):
         """
 
     def put_metric_data(
-        self, *, Namespace: str, MetricData: Sequence["MetricDatumTypeDef"]
-    ) -> None:
+        self, *, Namespace: str, MetricData: Sequence[MetricDatumTypeDef]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Publishes metric data points to Amazon CloudWatch.
 
@@ -552,10 +564,10 @@ class CloudWatchClient(BaseClient):
         FirehoseArn: str,
         RoleArn: str,
         OutputFormat: MetricStreamOutputFormatType,
-        IncludeFilters: Sequence["MetricStreamFilterTypeDef"] = ...,
-        ExcludeFilters: Sequence["MetricStreamFilterTypeDef"] = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
-        StatisticsConfigurations: Sequence["MetricStreamStatisticsConfigurationTypeDef"] = ...
+        IncludeFilters: Sequence[MetricStreamFilterTypeDef] = ...,
+        ExcludeFilters: Sequence[MetricStreamFilterTypeDef] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
+        StatisticsConfigurations: Sequence[MetricStreamStatisticsConfigurationTypeDef] = ...
     ) -> PutMetricStreamOutputTypeDef:
         """
         Creates or updates a metric stream.
@@ -571,7 +583,7 @@ class CloudWatchClient(BaseClient):
         StateValue: StateValueType,
         StateReason: str,
         StateReasonData: str = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Temporarily sets the state of an alarm for testing purposes.
 
@@ -595,7 +607,7 @@ class CloudWatchClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client/#stop_metric_streams)
         """
 
-    def tag_resource(self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceARN: str, Tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Assigns one or more tags (key-value pairs) to the specified CloudWatch resource.
 
