@@ -6,9 +6,9 @@ Type annotations for cloudwatch service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_cloudwatch.literals import AlarmExistsWaiterName
+    from mypy_boto3_cloudwatch.literals import ActionsSuppressedByType
 
-    data: AlarmExistsWaiterName = "alarm_exists"
+    data: ActionsSuppressedByType = "Alarm"
     ```
 """
 import sys
@@ -20,6 +20,7 @@ else:
 
 
 __all__ = (
+    "ActionsSuppressedByType",
     "AlarmExistsWaiterName",
     "AlarmTypeType",
     "AnomalyDetectorStateValueType",
@@ -48,6 +49,7 @@ __all__ = (
 )
 
 
+ActionsSuppressedByType = Literal["Alarm", "ExtensionPeriod", "WaitPeriod"]
 AlarmExistsWaiterName = Literal["alarm_exists"]
 AlarmTypeType = Literal["CompositeAlarm", "MetricAlarm"]
 AnomalyDetectorStateValueType = Literal["PENDING_TRAINING", "TRAINED", "TRAINED_INSUFFICIENT_DATA"]
@@ -174,6 +176,7 @@ ServiceName = Literal[
     "config",
     "connect",
     "connect-contact-lens",
+    "connectcampaigns",
     "connectparticipant",
     "cur",
     "customer-profiles",
@@ -210,6 +213,7 @@ ServiceName = Literal[
     "elbv2",
     "emr",
     "emr-containers",
+    "emr-serverless",
     "es",
     "events",
     "evidently",
@@ -283,6 +287,7 @@ ServiceName = Literal[
     "lookoutequipment",
     "lookoutmetrics",
     "lookoutvision",
+    "m2",
     "machinelearning",
     "macie",
     "macie2",
@@ -339,11 +344,13 @@ ServiceName = Literal[
     "rds-data",
     "redshift",
     "redshift-data",
+    "redshift-serverless",
     "rekognition",
     "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
+    "rolesanywhere",
     "route53",
     "route53-recovery-cluster",
     "route53-recovery-control-config",
