@@ -23,7 +23,7 @@ Usage::
 """
 from typing import Sequence
 
-from botocore.waiter import Waiter as Boto3Waiter
+from botocore.waiter import Waiter
 
 from .literals import AlarmTypeType, StateValueType
 from .type_defs import WaiterConfigTypeDef
@@ -31,7 +31,7 @@ from .type_defs import WaiterConfigTypeDef
 __all__ = ("AlarmExistsWaiter", "CompositeAlarmExistsWaiter")
 
 
-class AlarmExistsWaiter(Boto3Waiter):
+class AlarmExistsWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters/#alarmexistswaiter)
@@ -49,7 +49,7 @@ class AlarmExistsWaiter(Boto3Waiter):
         ActionPrefix: str = ...,
         MaxRecords: int = ...,
         NextToken: str = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists.wait)
@@ -57,7 +57,7 @@ class AlarmExistsWaiter(Boto3Waiter):
         """
 
 
-class CompositeAlarmExistsWaiter(Boto3Waiter):
+class CompositeAlarmExistsWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters/#compositealarmexistswaiter)
@@ -75,7 +75,7 @@ class CompositeAlarmExistsWaiter(Boto3Waiter):
         ActionPrefix: str = ...,
         MaxRecords: int = ...,
         NextToken: str = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists.wait)
